.. _musicmanager:
.. currentmodule:: gmusicapi.clients

Musicmanager Interface
======================

.. autoclass:: Musicmanager

Setup and login
---------------
.. automethod:: Musicmanager.perform_oauth
.. automethod:: Musicmanager.__init__
.. automethod:: Musicmanager.login
.. automethod:: Musicmanager.logout

Uploading Songs
---------------
.. automethod:: Musicmanager.upload

Downloading Songs
-----------------
.. automethod:: Musicmanager.get_uploaded_songs
.. automethod:: Musicmanager.get_purchased_songs
.. automethod:: Musicmanager.download_song

Misc
----
..automethod:: Musicmanager.get_quota
